==> haskell-th-reify-many-0.1.7-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.7
id: th-reify-many-0.1.7-89nxwFrujGnE4HpHWBm2JG
key: th-reify-many-0.1.7-89nxwFrujGnE4HpHWBm2JG
license: BSD3
maintainer: Michael Sloan <mgsloan at gmail>
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
author: Michael Sloan
exposed: True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
abi: fce2339e2bb9acfad6eeb91a269324b3
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-reify-many-0.1.7
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-reify-many-0.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/th-reify-many-0.1.7
hs-libraries: HSth-reify-many-0.1.7-89nxwFrujGnE4HpHWBm2JG
depends:
    base-4.9.1.0 containers-0.5.7.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY template-haskell-2.11.1.0
    th-expand-syns-0.4.3.0-IkppgMRU8HaKb8WgclTkO3
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-reify-many-0.1.8-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-reify-many.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-reify-many
version: 0.1.8
id: th-reify-many-0.1.8-6KXxKZBHJWMKdLDbo2MoSN
key: th-reify-many-0.1.8-6KXxKZBHJWMKdLDbo2MoSN
license: BSD3
maintainer: Michael Sloan <mgsloan at gmail>
stability: Experimental
homepage: http://github.com/mgsloan/th-reify-many
synopsis: Recurseively reify template haskell datatype info
description:
    @th-reify-many@ provides functions for recursively reifying top
    level declarations.  The main intended use case is for enumerating
    the names of datatypes reachable from an initial datatype, and
    passing these names to some function which generates instances.
category: Template Haskell
author: Michael Sloan
exposed: True
exposed-modules:
    Language.Haskell.TH.ReifyMany
    Language.Haskell.TH.ReifyMany.Internal
abi: 063250a907bab48661b74c8890b44d9c
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-reify-many-0.1.8
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-reify-many-0.1.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/th-reify-many-0.1.8
hs-libraries: HSth-reify-many-0.1.8-6KXxKZBHJWMKdLDbo2MoSN
depends:
    base-4.9.1.0 containers-0.5.7.1 mtl-2.2.1-BLKBelFsPB3BoFeSWSOYj6
    safe-0.3.15-2Yd45VWFfdcKqKyispOifY template-haskell-2.11.1.0
    th-expand-syns-0.4.3.0-IkppgMRU8HaKb8WgclTkO3
haddock-interfaces: /usr/share/doc/haskell-th-reify-many/html/th-reify-many.haddock
haddock-html: /usr/share/doc/haskell-th-reify-many/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
